\name{Select.ontology}
\alias{Select.ontology}
\alias{Select.ontology.evidence}
\alias{Select.Funcat.evidence}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Selection of functional classes associated to genes }
\description{
  These functions select GO or FunCat classes associated to gene names according to a given ontology and evidence
}
\usage{
Select.ontology(x, ontology = "BP")
Select.ontology.evidence(x, ontology = "BP", evidence = "")
Select.Funcat.evidence(x, evidence = "")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ a generic entry of an environment representing an assay or platform specific annotation }
  \item{ontology}{ the GO ontology to be selected: it needs to be: "BP" (def.), "MF" or "CC" }
	\item{evidence}{ evidence code. For FunCat (\code{Select.Funcat.evidence}) it can be a vector with one ore more FunCat numeric evidence codes.
	For GO it may be a vector with 1 or more of the following entries:
    \item IMP: inferred from mutant phenotype
    \item IGI: inferred from genetic interaction
    \item IPI: inferred from physical interaction
    \item ISS: inferred from sequence similarity
    \item IDA: inferred from direct assay
    \item IEP: inferred from expression pattern
    \item IEA: inferred from electronic annotation
    \item TAS: traceable author statement
    \item NAS: non-traceable author statement
    \item ND: no biological data available
    \item IC: inferred by curator 
    \item "": no entry: all the evidence codes are accepted (default)
  }
}
\details{
  \code{Select.ontology}  selects a GO class, while  \code{Select.ontology.evidence} 
	selects genes with respect to an ontology and evidence code of the annotations.
	It can be used with eapply, to extract from the environment that associates a gene/gene product to
  its gene ontology classes (e.g. YEASTGO) the entries that match a specific ontology and evidence.	
	\code{Select.Funcat.evidence} select a FunCat class with respect to the evidence code of the annotation.
	It can be used with eapply, to extract from the environment that associates a gene/gene product to
  its FunCat classes (e.g. YEASTFUNCAT) the entries that match a specific ontology and evidence.
}
\value{
 \code{Select.ontology} returns the GOID of the GO class if it matches the ontology, otherwise the string "NOCLASS".
 \code{Select.ontology.evidence} returns a vector with the GO ID of the ontology classes associated to the entry x, for 
  the selected ontology and evidence codes. Duplicated classes are removed.
	\code{Select.Funcat.evidence} returns a vector with the Funcat ID of the  classes associated to the entry x, for 
 the selected evidence codes. Duplicated classes are removed.
}
\seealso{ \code{\link{Get.all.GO.classes}}, \code{\link{Get.GO.specific.classes}} }
\examples{
# Selection of genes annotated with TAS evidence in the MF GO ontology in A. thaliana;
 data(ATGO);
 A.th.names.to.GO <- eapply(ATGO, Select.ontology.evidence, ontology="MF", evidence="TAS"); 
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ manip }
