\name{ClassNames}
\alias{Get.Term.Definition}
\alias{Get.classes}
\alias{Get.all.Funcat.classes}
\alias{Get.all.GO.classes}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Getting names or information about GO and FunCat classes }
\description{
  These are a set of functions to obtain information or class names from the FunCat taxonomy
	and Gene Ontology.
}
\usage{
Get.Term.Definition(goid)
Get.classes(NamesToGO)
Get.all.Funcat.classes()
Get.all.GO.classes(ontology = "BP")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{goid}{ GO ID of a GO class (character) }
	\item{NamesToGO}{  named list of vectors. Each element of the list corresponds to a named yeast gene and the elements
  of the vector are the corresponding GO/FunCat classes ID. }
	\item{ontology}{ a char vector denoting the ontology: BP (default), MF, CC }
}
\details{
  \code{Get.Term.Definition} returns the GO term and definition for a given GO ID.
	The function \code{Get.classes} obtains the GO or Funcat classes from the named list of genes. More precisely
	It performs of a union of all the classes associated to the named list of genes.
	\code{Get.all.Funcat.classes} returns the FunCat ID of all the FunCat classes.
	The function \code{Get.all.GO.classes} gets all the GO classes from a given ontology
}
\value{
  \code{Get.Term.Definition} returns the GO term and definition for a given GO ID.
	\code{Get.classes} returns a vector of GOID or FunCat ID. 
	\code{Get.all.Funcat.classes} returns a character vector of all the Funcat classes.
	\code{Get.all.GO.classes} returns a character vector of the GO classes.
}
\examples{
 Get.Term.Definition("GO:0008150");
 Yeast.Funcat.specific <- Get.yeast.Funcat.specific.classes();
 Get.classes(Yeast.Funcat.specific);
 Get.all.Funcat.classes();
 Get.all.GO.classes(ontology = "MF");
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ manip }
