\name{Get.matrix.data.for.two.selected.classes}
\alias{Get.matrix.data.for.two.selected.classes}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Data matrix construction for a binary classification problem: negatives as belonging to a specific class }
\description{
  This function builds a data set for a specific class within the FunCat taxonomy or GO.
	The positive classes are assigned according the specified GO/Funcat class, while the negative examples belongs to
	another specific GO/Funcat class.
}
\usage{
Get.matrix.data.for.two.selected.classes(Table.gene.class, classid1, classid2, data.matrix)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{Table.gene.class}{ a data frame with columns corresponding to Funcat or GO classes and rows to a given gene. If a gene
  belongs to the Funcat/GO class the corresponding column is set to 1 otherwise to 0. }
  \item{classid1}{ GO/FunCat ID of the the positive class to be extracted from Table.gene.class }
  \item{classid2}{ GO/FunCat ID of the the negative class to be extracted from Table.gene.class }
  \item{data.matrix}{matrix of the  data from which  genes of the positive and negative classes are extracted. 
	                   Rows correspond to genes and columns to the features associated to each gene }
}
\details{
   This function returns a dataset for dichotomic classification of GO/Funcat classes of genes where the two classes are two distinct GO/Funcat
 classes. 
 It may be used with both GO and Funcat ontologies and with any species.
 N.B. : gene names of the data (rownames) need to be of the same type of the gene names stored in the Table.gene.class.
 For instance they must be both systematic names of the genes for the yeast or Locus Link identifiers for human gene names.
}
\value{
  A list with four elements:
  \item{X}{data frame of the data values (rows are genes, columns variables)}
  \item{labels }{a factor with the labels of the classes: 1 for \code{classid1}, 2 for \code{classid2}}
	\item{n.pos }{number of positive examples (\code{classid1})}
	\item{n.neg }{number of negaive examples (\code{classid2})}
}

\seealso{ \code{\link{Get.matrix.data.for.classid}} }
\examples{
# building a data set of gene expression data for the yeast (considering only TAS annotations) for the classes "GO:0000902" and "GO:0048015", 
Yeast.specific.TAS <- Get.yeast.GO.specific.classes(evidence="TAS");
Yeast.general.TAS <- Get.yeast.GO.all.classes(Yeast.specific.TAS);
Yeast.GO.Table.TAS <- Build.GO.class.labels(Yeast.general.TAS);
library(yeastCC);
data.expression <- exprs(spYCCES);
data.expression.specific.classes <- Get.matrix.data.for.two.selected.classes(Yeast.GO.Table.TAS, classid1="GO:0000902", classid2="GO:0048015", data.expression);
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ manip }
