\name{Get.matrix.data.without.ancestors}
\alias{Get.matrix.data.without.ancestors}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{  Data matrix construction for a binary classification problem: negatives not from ancestors }
\description{
This function builds a data set for a specific class within the FunCat taxonomy or GO.
The positive classes are assigned according the specified GO/Funcat class.
A negative example for a node is any example whose multilabel does not include that node
and any of its ancestors.
}
\usage{
Get.matrix.data.without.ancestors(Table.gene.class, classid, data.matrix, ontology = "Funcat", ratio.negative = 0, common.genes = NULL, seed = 1, include.unknown = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{Table.gene.class}{ a data frame with columns corresponding to Funcat or GO classes and rows to a given gene. If a gene
  belongs to the Funcat/GO class the corresponding column is set to 1 otherwise to 0. }
  \item{classid}{ GO/FunCat ID of the the class to be extracted from Table.gene.class }
  \item{data.matrix}{ matrix of the  data from which  genes of the positive and negative classes are extracted. Rows correspond to genes and columns to the features
	                    associated to each gene }
  \item{ontology}{ a character vector corresponding to the selected ontology: Funcat  (default), BP, MF, CC }
  \item{ratio.negative}{ the proportion of negative examples w.r.t the positives. If 0 (def.) all the available negative examples are used }
  \item{common.genes}{ character vector: if it set to NULL (default) only the genes common to the given ontology and data set are considered; 
  otherwise only the genes of the common.genes are considered }
  \item{seed}{ seed for the random generator }
  \item{include.unknown}{ boolean. If FALSE (def) classes labeled as unknown are not included as possible negative examples }
}
\details{
For a gene and its associate data x with multilabel \eqn{y \in {0,1}^N} where \eqn{N} is the number of nodes classes,
with \eqn{PAR(i)} parent nodes of \eqn{i}, and \eqn{ANC(i)} the ancestors of \eqn{i}, we have that the data set \eqn{D(i)^+} of the positive examples is:
\deqn{D(i)^+ = \{ x |  y_i = 1\}} while the negatives are \deqn{D(1)^- = \{ x | y_{ANC(i)} = 0, y_i = 0\}}
The data set given as input must be in matrix format, with genes on the rows and variables associated to genes as columns;
the rows of the data matrix needs to be named with the gene names (e.g. ORF ID for yeast or Entrez Gene IDs for human or mouse).
Possible data could be, e.g., gene expression or phylogenetic data.
This function can  be used with both GO and Funcat ontologies and with any species.
It is possible to select a random subset of the negatives of a specified size.
Note the by default examples labeled as unknown (that is genes of classes 98 and 99 with FunCat, and
genes with only 1 label with GO ontologies) are not included as possible negative examples, but it is possible to
include them as negatives by setting to TRUE the boolean argument \code{include.unknown}.
The data  are associated to the selected genes and are returned together with the labels of the classes: 1 for positive examples and 2 for negatives.
The function considers only gene names that are common to the ontologies and the available data.
N.B. : gene names of the data matrix need to be of the same type of the gene names stored in the \code{Table.gene.class}.
For instance they must be both systematic names of the genes for the yeast or Locus Link identifiers for human gene names.
}
\value{
   A list with four elements:
  \item{X }{matrix of the data values (rows are genes, columns variables)}
  \item{labels }{a factor with the labels of the classes: 1 for classid (positives), 2 for negatives (not belonging to classid).}
	\item{n.pos }{number of positive examples}
	\item{n.neg }{number of negaive examples}
}
\seealso{ \code{\link{Get.matrix.data.from.parent.only}}, \code{\link{Get.matrix.data.for.classid}}}
\examples{
# building a data set of gene expression data for the yeast  for the class "GO:0009102", 
Yeast.specific <- Get.yeast.GO.specific.classes(evidence="");
Yeast.general <- Get.yeast.GO.all.classes(Yeast.specific);
Yeast.GO.Table <- Build.GO.class.labels(Yeast.general);
library(yeastCC);
data.expression <- exprs(spYCCES);
data.expression.specific.class2 <-Get.matrix.data.without.ancestors(Yeast.GO.Table, classid="GO:0009102", data.expression, ontology = "BP");
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ manip }
