\name{hcgene-package}
\alias{hcgene-package}
\alias{hcgene}
\docType{package}
\title{HCGene: a software tool to support the hierarchical classification of genes}
\description{
The R package \emph{HCGene} (\emph{H}ierarchical \emph{C}lassification of \emph{Gene}s), built on top of Bioconductor libraries, 
implements methods to process and analyze the directed acyclic graphs of the \emph{Gene Ontology (GO)} and the trees of the \emph{FunCat} 
taxonomy of genes.
\emph{HCGene} has been designed to support the hierarchical classification of genes, but in principle it
can also be used for other prediction or exploratory tasks that take into account the hierarchical structure of gene ontologies.
\emph{HCGene} allows the extraction of subgraphs and subtrees related to specific biological problems,
the labelling of genes and gene products with multiple and hierarchical functional classes, and
the association of different types of bio-molecular data to genes for learning to predict their functions.
}
\details{
\tabular{ll}{
Package: \tab hcgene\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2007-10-15\cr
License: \tab GNU/GPL\cr
}

Assigning functions to unannotated gene products using large-scale bio-molecular data is a key
issue in functional genomics and bioinformatics.

Most computational methods to predict the functions of genes have been based on a "flat" multiclass setting of the classification
problem, without taking into account the hierarchical structure of gene classes.

Nevertheless, the structure of the \emph{Gene Ontology (GO)} and \emph{FunCat} taxonomies,
requires a new setting of the classical multi-class classification problem.
Indeed these ontologies assign multiple classes to gene/gene products, with  annotations available at different degree of resolution and reliability, and with
hierarchical relationships between the classes. 
More precisely the \emph{GO} provides a taxonomy structured as a Directed Acyclic Graph (DAG), while 
\emph{FunCat} organizes functional categories of genes according to a tree.

In this context the problem of the gene function prediction must be restated in a multi-label, hierarchical and partial-path setting
of the classical statistical and machine learning multi-class classification problem.

\emph{HCGene} implements methods to process complex taxonomies structured as graphs (e.g. DAG or trees)
with thousands of nodes and edges, in order to extract subgraphs related to the specific biological process under investigation,
or to properly associates multiple functional classes to gene and gene products according to the hierarchical structure of 
the FunCat trees or GO DAGs, or to associate gene products to multiple data types (e.g. gene expression data, phylogenetic or
protein interaction data) used to infer the function of unknown genes.

Schematically the main functionalities of the software library can be summarized as follows:

\item Graph processing: 
building of hierarchical structures covering the main  ontologies (trees and graphs);
methods to analyze the structure and the relationships between functional classes (e.g. distribution of node/classes with respect to their depth, in and out-degree,
cardinality of classes or labels, distribution of leaves at different levels);
methods to extract biologically meaningful structures from GO DAGs and FunCat trees.
\item Multi-label generation:
extraction of the most specific annotations and building of the full annotation of genes exploiting the transitive relationships between classes;
building of the multi-labeling for each gene using compact representations;
mapping functions to associate gene names or identifiers (e.g. ORF ID or EntrezGene IDs) to functional classes 
\item Data building: 
methods to associate gene names to different types of data;
methods to select positive and negative examples for each class according to different strategies;
methods to build data relative to specific functional classes.

Moreover functions to graphically show the results of statistical analyses, as well as to draw subgraphs of GO and FunCat ontologies are provided .

The software library is built on top of the \emph{Bioconductor} packages \pkg{graph}, \pkg{GO}, \pkg{GOstats}, and \pkg{Rgraphviz} 
to provide functionalities 
related to the \emph{GO} ontology, while for the \emph{FunCat} taxonomies the software has been built from scratch using the hierarchical schemes 
and functional annotations obtained from the MIPS website (\url{http://mips.gsf.de}). 

\emph{HCGene}  has been designed to support the supervised hierarchical classification of genes, 
but it can also be used to support the development of methods that incorporate a priori biological knowledge into analysis, 
by exploiting the \emph{HCGene} functions for the Funcat and GO graph processing, and for the  association of genes to the functional classes.
}
\author{
Giorgio Valentini <valentini@dsi.unimi.it>.
}
\references{
Barutcuoglu, Z., Schapire, R.E. and Troyanskaya, O.G., Hierarchical multi-label prediction of gene function,  \emph{Bioinformatics}, 
22(7), 830-836, 2006.

Dopazo, J., Functional Interpretation of Microarray Experiments, \emph{OMICS}, 10(3), 2006.

Harris, M.A. and others, The Gene Ontology (GO) database and informatics resource, \emph{Nucleic Acid Res.}, 32,  D258--D261, 2004.

Lewis, D.P., Jebara, T. and Noble, W.S., Support vector machine learning from heterogeneous data: 
an empirical analysis using protein sequence and structure, \emph{Bioinformatics}, 22(22),  2753-2760, 2006.

Pavlidis, P.,  Weston, J., Cai, J. and Noble, W.S., Learning gene functional classification from multiple data, \emph{J. Comput. Biol.}, 9, 401-411, 2002. 

Ruepp, A and others, The FunCat, a functional annotation scheme for systematic classification of proteins from whole genomes, 
\emph{Nucleic Acid Res.}, 32, 5539-5545, 2004.
}

\keyword{ package }
\seealso{
\emph{graph}, \emph{GO}, \emph{GOstats}, \emph{Rgraphviz}
}
