\name{Get.all.common.genes}
\alias{Get.all.common.genes}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Getting genes common to different data sets }
\description{
  Function that returns the names of genes common to different data sets and a given ontology
  It may be used with both GO and Funcat ontologies and with any species.
  An arbitrary number of data sets in matrix format may be passed as arguments (but at least 1 is needed)
}
\usage{
Get.all.common.genes(Table.gene.class, data1, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{Table.gene.class}{  a data frame with columns corresponding to Funcat or GO  classes and rows to a given gene. If a gene
 belongs to the Funcat/GO class the corresponding column is set to 1 otherwise to 0 }
  \item{data1}{ the first data set (mandatory) }
  \item{\dots}{ other possible data sets }
}
\value{
  a vector of common gene names among the different data sets
}
\seealso{ \code{\link{Get.matrix.data.for.classid}}, \code{\link{Get.matrix.data.without.ancestors}}, \code{\link{Get.matrix.data.from.parent.only}} }
\examples{
# Selection of yeast genes with TAS annotation common to the gene expression data spYCCES 
# and to the phylogenetic data obtained from the package scehomology
Yeast.specific.TAS <- Get.yeast.GO.specific.classes(evidence="TAS");
Yeast.general.TAS <- Get.yeast.GO.all.classes(Yeast.specific.TAS);
Yeast.GO.Table.TAS <- Build.GO.class.labels(Yeast.general.TAS);
library(yeastCC);
data.expression <- exprs(spYCCES);
l<-Build.list.yeast.homology.data();
data.phylo<-Do.binary.data.homology(l);
common.genes <- Get.all.common.genes(Yeast.GO.Table.TAS, data.expression, data.phylo);
}
\keyword{ manip }
